# UI/UX Feedback

**ID:** Feedback-20260219-171622
**URL:** http://127.0.0.1:5858
**Date:** 2026-02-19 17:18:12

## Selected Elements

- `{'selector': '#workplace-tree', 'parents': ['div#content-body', 'div.workplace-container', 'div#workplace-sidebar', 'div.workplace-sidebar-content']}`

## Feedback

when I try to take the screenshot from uiux feedback for the ideation page, it;s extramely slow, even stuck there, something is wrong

